@@ -10,9 +10,7 @@ test_that("parse_remote", {
 })
 
 test_that("resolve_remote", {
-
-  skip_if_offline()
-  skip_on_cran()
+  setup_fake_apps()
 
   conf <- current_config()
   cache <- list(package = NULL, metadata = pkgcache::get_cranlike_metadata_cache())
@@ -20,44 +18,36 @@ test_that("resolve_remote", {
   ## Absolute path
   path <- get_fixture("foobar_1.0.0.tar.gz")
   ref <- paste0("local::", path)
-  res <- synchronise(
-    resolve_remote_local(parse_pkg_ref(ref), TRUE, conf,
-                         cache, dependencies = FALSE)
-  )
+  res <- synchronise(resolve_remote_local(
+    parse_pkg_ref(ref),
+    TRUE, conf,
+    cache,
+    dependencies = FALSE
+  ))
 
-  expect_true(is.list(res))
-  expect_true(res$ref == ref)
-  expect_true(res$type == "local")
-  expect_true(res$direct)
-  expect_true(res$status == "OK")
-  expect_true(res$package == "foobar")
-  expect_true(res$version == "1.0.0")
-  expect_equal(res$unknown_deps, character(0))
-  expect_equal(res$sources[[1]], paste0("file://", normalizePath(path)))
-  expect_equal(res$metadata[["RemoteType"]], "local")
-  expect_equal(res$metadata[["RemotePkgRef"]], ref)
+  res$metadata <- as.list(res$metadata)
+  # seems really hard to remove the path
+  res$sources[[1]] <- basename(res$sources[[1]])
+  expect_snapshot(res)
 
   ## Relative path?
   fix_dir <- fixture_dir()
   ref2 <- paste0("local::", "foobar_1.0.0.tar.gz")
   withr::with_dir(
     fix_dir,
-    res <- synchronise(
-      resolve_remote_local(parse_pkg_ref(ref2), TRUE, conf,
-                         cache, dependencies = FALSE)
-    )
+    res <- synchronise(resolve_remote_local(
+      parse_pkg_ref(ref2),
+      TRUE,
+      conf,
+      cache,
+      dependencies = FALSE
+    ))
   )
 
-  expect_true(is.list(res))
-  expect_true(res$ref == ref2)
-  expect_true(res$type == "local")
-  expect_true(res$direct)
-  expect_true(res$status == "OK")
-  expect_true(res$package == "foobar")
-  expect_true(res$version == "1.0.0")
-  expect_equal(res$sources[[1]], paste0("file://", normalizePath(path)))
-  expect_equal(res$metadata[["RemoteType"]], "local")
-  expect_equal(res$metadata[["RemotePkgRef"]], ref2)
+  res$metadata <- as.list(res$metadata)
+  # seems really hard to remove the path
+  res$sources[[1]] <- basename(res$sources[[1]])
+  expect_snapshot(res)
 })
 
 test_that("resolution error", {
@@ -76,8 +66,7 @@ test_that("resolution error", {
 })
 
 test_that("download_remote", {
-  skip_if_offline()
-  skip_on_cran()
+  setup_fake_apps()
 
   dir.create(tmp <- tempfile())
   dir.create(tmp2 <- tempfile())
@@ -89,20 +78,22 @@ test_that("download_remote", {
   conf$package_cache_dir <- tmp2
   cache <- list(
     package = pkgcache::package_cache$new(conf$package_cache_dir),
-    metadata = pkgcache::get_cranlike_metadata_cache())
+    metadata = pkgcache::get_cranlike_metadata_cache()
+  )
 
   ## Absolute path
   path <- get_fixture("foobar_1.0.0.tar.gz")
   ref <- paste0("local::", path)
 
   rem <- pkg_plan$new(ref)
-  rem$resolve()
+  suppressMessages(rem$resolve())
   res <- rem$get_resolution()
 
   target <- file.path(conf$cache_dir, res$target[1])
+  tree <- paste0(target, "-tree")
   mkdirp(dirname(target))
   download <- function(res) {
-    download_remote_local(res, target, conf, cache, on_progress = NULL)
+    download_remote_local(res, target, tree, conf, cache, on_progress = NULL)
   }
   dl1 <- synchronise(download(res[1,]))
   expect_equal(dl1, "Got")
@@ -119,16 +110,54 @@ test_that("download_remote", {
   })
 
   target <- file.path(conf$cache_dir, res$target[1])
+  tree <- paste0(target, "-tree")
   mkdirp(dirname(target))
-  dl1 <- download_remote_local(res, target, conf, cache, on_progress = NULL)
+  dl1 <- download_remote_local(res, target, tree, conf, cache, on_progress = NULL)
 
   expect_equal(dl1, "Got")
   expect_true(file.exists(target))
 })
 
+test_that("download_remote directory", {
+  setup_fake_apps()
+
+  dir.create(tmp <- tempfile())
+  dir.create(tmp2 <- tempfile())
+  dir.create(tmp3 <- tempfile())
+  on.exit(unlink(c(tmp, tmp2, tmp3), recursive = TRUE), add = TRUE)
+
+  conf <- current_config()
+  conf$platforms <- "source"
+  conf$cache_dir <- tmp
+  conf$package_cache_dir <- tmp2
+  cache <- list(
+    package = pkgcache::package_cache$new(conf$package_cache_dir),
+    metadata = pkgcache::get_cranlike_metadata_cache()
+  )
+
+  path <- get_fixture("foobar_1.0.0.tar.gz")
+  untar(path, exdir = tmp3)
+  path <- file.path(tmp3, "foobar")
+  ref <- paste0("local::", path)
+
+  rem <- pkg_plan$new(ref)
+  suppressMessages(rem$resolve())
+  res <- rem$get_resolution()
+
+  target <- file.path(conf$cache_dir, res$target[1])
+  tree <- paste0(target, "-tree")
+  mkdirp(dirname(target))
+  download <- function(res) {
+    download_remote_local(res, target, tree, conf, cache, on_progress = NULL)
+  }
+  dl1 <- synchronise(download(res[1,]))
+  expect_equal(dl1, "Got")
+  expect_true(file.exists(tree))
+  expect_true(is.dir(tree))
+})
+
 test_that("download_remote error", {
-  skip_if_offline()
-  skip_on_cran()
+  setup_fake_apps()
 
   dir.create(tmp <- tempfile())
   on.exit(unlink(tmp, recursive = TRUE), add = TRUE)
@@ -156,6 +185,69 @@ test_that("download_remote error", {
 })
 
 test_that("satisfy", {
+  expect_snapshot({
+    "different package name, FALSE"
+    satisfy_remote_local(
+      list(package = "foo"),
+      list(package = "bar")
+    )
+
+    "different type is bad"
+    satisfy_remote_local(
+      list(
+        package = "foo",
+        remote = list(list(package = NA_character_)),
+        path = "/tmp/foo"
+      ),
+      list(
+        type = "notgood",
+        package = "foo",
+        path = "/tmp/foo"
+      )
+    )
+
+    "any package name is good, good"
+    satisfy_remote_local(
+      list(
+        package = "foo",
+        remote = list(list(package = NA_character_, path = "/tmp/foo"))
+      ),
+      list(
+        type = "local",
+        package = "foo",
+        remote = list(list(path = "/tmp/foo"))
+      )
+    )
+
+    "requested a different package, bad"
+    satisfy_remote_local(
+      list(
+        package = "foo",
+        remote = list(list(package = "bar", path = "/tmp/foo"))
+      ),
+      list(
+        type = "local",
+        package = "foo",
+        remote = list(list(package = "bar", path = "/tmp/foo"))
+      )
+    )
+
+    "different paths are bad"
+    satisfy_remote_local(
+      list(
+        package = "foo",
+        remote = list(list(package = "foo", path = "/tmp/foo"))
+      ),
+      list(
+        type = "local",
+        package = "foo",
+        remote = list(list(package = "foo", path = "/tmp/foo2"))
+      )
+    )
+  })
+})
+
+test_that("installedok", {
   ## Always FALSE, independently of arguments
-  expect_false(satisfy_remote_local())
+  expect_false(installedok_remote_local())
 })
